KeyValueMapSerializer

Struct KeyValueMapSerializer 

struct KeyValueMapSerializer<'a, M> {
    delegate: &'a mut M,
    is_human_readable: bool,
    content: Vec<(Content, Content)>,
    next_is_magic_key: bool,
    key: Option<Content>,
    tmp: Option<Content>,
}
Serialize a map to a key and value pair of a map.

This requires that the map has one element which serializes using the magic $key$ key.

Fields

delegate: &'a mut Mis_human_readable: boolcontent: Vec<(Content, Content)>next_is_magic_key: boolkey: Option<Content>tmp: Option<Content>