struct KeyValueSeqSerializer<'a, M> {
delegate: &'a mut M,
is_human_readable: bool,
content: Vec<Content>,
key: Option<Content>,
}Expand description
Serialize a sequence to a key and value pair of a map.
This requires that the sequence has at least one element.
Fields
delegate: &'a mut Mis_human_readable: boolcontent: Vec<Content>key: Option<Content>Trait Implementations
Sourceimpl<M> SerializeSeq for KeyValueSeqSerializer<'_, M>where
M: SerializeMap,
impl<M> SerializeSeq for KeyValueSeqSerializer<'_, M>where
M: SerializeMap,