struct KeyValueTupleSerializer<'a, M> {
delegate: &'a mut M,
is_human_readable: bool,
content: Vec<Content>,
key: Option<Content>,
}Expand description
Serialize a tuple to a key and value pair of a map.
This requires that the tuple has at least one element.
Fields
delegate: &'a mut Mis_human_readable: boolcontent: Vec<Content>key: Option<Content>Trait Implementations
Sourceimpl<M> SerializeTuple for KeyValueTupleSerializer<'_, M>where
M: SerializeMap,
impl<M> SerializeTuple for KeyValueTupleSerializer<'_, M>where
M: SerializeMap,