struct KeyValueTupleStructSerializer<'a, M> {
delegate: &'a mut M,
is_human_readable: bool,
name: &'static str,
content: Vec<Content>,
key: Option<Content>,
}Expand description
Serialize a tuple struct to a key and value pair of a map.
This requires that the tuple struct has at least one element.
Fields
delegate: &'a mut Mis_human_readable: boolname: &'static strcontent: Vec<Content>key: Option<Content>Trait Implementations
Sourceimpl<M> SerializeTupleStruct for KeyValueTupleStructSerializer<'_, M>where
M: SerializeMap,
impl<M> SerializeTupleStruct for KeyValueTupleStructSerializer<'_, M>where
M: SerializeMap,