struct KeyValueMapSerializer<'a, M> {
delegate: &'a mut M,
is_human_readable: bool,
content: Vec<(Content, Content)>,
next_is_magic_key: bool,
key: Option<Content>,
tmp: Option<Content>,
}Expand description
Serialize a map to a key and value pair of a map.
This requires that the map has one element which serializes using the magic $key$ key.
Fields
delegate: &'a mut Mis_human_readable: boolcontent: Vec<(Content, Content)>next_is_magic_key: boolkey: Option<Content>tmp: Option<Content>Trait Implementations
Sourceimpl<M> SerializeMap for KeyValueMapSerializer<'_, M>where
M: SerializeMap,
impl<M> SerializeMap for KeyValueMapSerializer<'_, M>where
M: SerializeMap,
Sourcetype Error = <M as SerializeMap>::Error
type Error = <M as SerializeMap>::Error
Must match the
Error type of our Serializer.Sourcefn serialize_key<T>(&mut self, key: &T) -> Result<(), Self::Error>
fn serialize_key<T>(&mut self, key: &T) -> Result<(), Self::Error>
Serialize a map key. Read more