struct KeyValueStructSerializer<'a, M> {
delegate: &'a mut M,
is_human_readable: bool,
name: &'static str,
content: Vec<(&'static str, Content)>,
key: Option<Content>,
}Expand description
Serialize a struct to a key and value pair of a map.
This requires that the struct has one field named $key$.
Fields
delegate: &'a mut Mis_human_readable: boolname: &'static strcontent: Vec<(&'static str, Content)>key: Option<Content>Trait Implementations
Sourceimpl<M> SerializeStruct for KeyValueStructSerializer<'_, M>where
M: SerializeMap,
impl<M> SerializeStruct for KeyValueStructSerializer<'_, M>where
M: SerializeMap,